# REPLACE THIS WITH SOME REAL TESTS!

from unittest import TestCase

from muprocdurham.myclass import MyClass


class TestTemplate(TestCase):

    def test_implementing_subtypes(self):
        c = MyClass()
        c.some_function(None, None)
